==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/pt_BR.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link público",
    "Photos" : "Fotos",
    "On This Day" : "Neste Dia",
    "Your memories under your control" : "Suas memórias sob seu controle",
    "All media" : "Todas as mídias",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Neste dia",
    "Shared with you" : "Compartilhado com você",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configurações de fotos",
    "Mark selection as favorite" : "Marcar seleção como favorito",
    "Add selection to favorites" : "Adicionar seleção aos favoritos",
    "Remove selection from favorites" : "Remover seleção dos favoritos",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localização do álbum",
    "Back" : "Voltar",
    "Add collaborators" : "Adicionar colaboradores",
    "Save" : "Salvar",
    "Create album" : "Criar álbum",
    "Add to Album" : "Adicionar ao Álbum",
    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
    "Shared by" : "Compartilhado por",
    "Create a new album." : "Criar um novo álbum.",
    "Create new album" : "Criar novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%n item","%n fotos e vídeos","%n fotos e vídeos"],
    "Failed to fetch collaborators list." : "Falha ao obter a lista de colaboradores.",
    "Failed to update album." : "Falha ao atualizar álbum.",
    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
    "Search people or groups" : "Pesquisar pessoas ou grupos",
    "No recommendations. Start typing." : "Sem recomendações. Comece a digitar.",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remover {collaboratorLabel} da lista de colaboradores",
    "Copy the public link" : "Copiar link público",
    "Public link copied!" : "Link público copiado!",
    "Copy public link" : "Copiar link público",
    "Delete the public link" : "Excluir link público",
    "Create public link share" : "Criar compartilhamento de link público",
    "Share via public link" : "Compartilhar via link público",
    "This collection does not exist" : "Esta coleção não existe",
    "An error occurred" : "Ocorreu um erro",
    "No picture for this day" : "Nenhuma foto para este dia",
    "Picture taken on this day will show up here." : "Uma foto tirada neste dia aparecerá aqui.",
    "More photos from this day" : "Mais fotos deste dia",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto não atribuída","%n fotos não atribuídas","%n fotos não atribuídas"],
    "Favorite" : "Favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abrir a imagem \"{name}\" em tamanho real",
    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho real",
    "Select image {imageName}" : "Selecionar imagem {imageName}",
    "Open the \"{name}\" folder" : "Abrir pasta \"{name}\"",
    "Back to {folder}" : "Voltar para {folder}",
    "Go back" : "Voltar",
    "Share this folder" : "Compartilhar esta pasta",
    "Dates" : "Datas",
    "Jump to specific date in list" : "Ir para uma data específica na lista",
    "Jump to {date}" : "Ir para {date}",
    "Add to {destination}" : "Adicionar a {destination}",
    "The destination folder is owned by {owner}" : "A pasta de destino pertence a {owner}",
    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
    "_{years} year ago_::_{years} years ago_" : ["há {years} ano","há {years} anos","há {years} anos"],
    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
    "Delete source directory" : "Excluir diretório de origem",
    "Pick folder" : "Selecionar pasta",
    "Select a source folder for your media" : "Selecione uma pasta de origem para sua mídia",
    "All folders" : "Todas as pastas",
    "Add a Photos source for the timelines" : "Adicione uma fonte de Fotos para as linhas do tempo",
    "Add folder" : "Adicionar pasta",
    "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
    "Home" : "Início",
    "Choose default Photos upload and Albums location" : "Escolha o local padrão para upload de Fotos e Álbuns",
    "Choose a different folder" : "Escolha uma pasta diferente",
    "View" : "Exibição",
    "Media folders" : "Pastas de mídia",
    "Choose the folders from where photos and videos are shown." : "Escolha as pastas de onde as fotos e os vídeos são exibidos.",
    "Upload folder" : "Pasta para uploads",
    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta na qual as fotos e os álbuns serão carregados.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarcar todos",
    "Add photos to this album" : "Adicionar fotos a este álbum",
    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
    "Open actions menu" : "Abrir menu de ações",
    "Edit album details" : "Modificar detalhes do álbum",
    "Download all files in album" : "Baixar todos os arquivos do álbum",
    "Delete album" : "Excluir álbum",
    "Download selected files" : "Baixar arquivos selecionados",
    "Remove selection from album" : "Remover seleção do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum ainda não tem fotos ou vídeos!",
    "Add photos to {albumName}" : "Adicionar fotos a {albumName}",
    "Manage collaborators" : "Gerenciar colaboradores",
    "Save collaborators for this album." : "Salvar colaboradores deste álbum.",
    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
    "There is no album yet!" : "Ainda não existe um álbum!",
    "This person could not be found" : "Não foi possível encontrar essa pessoa",
    "Rename person" : "Renomear pessoa",
    "Merge with different person" : "Unir com outra pessoa",
    "Download selected photos" : "Baixar fotos selecionadas",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remover pessoa",
    "Name of this person" : "Nome desta pessoa",
    "Save." : "Salvar.",
    "Merge person" : "Unir pessoa",
    "Move to different person" : "Mover para uma pessoa diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto para uma pessoa diferente","Mover fotos para uma pessoa diferente","Mover fotos para uma pessoa diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remover foto desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
    "This might take some time depending on the size of your photo library." : "Isso pode levar algum tempo, dependendo do tamanho de sua biblioteca de fotos.",
    "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
    "This folder does not exist" : "Esta pasta não existe",
    "Loading folders …" : "Carregando pastas …",
    "No photos in here" : "Não há fotos aqui",
    "Taken on {date} at {time}" : "Tirada em {data} às {time}",
    "This place does not have any photos or videos yet!" : "Este espaço ainda não tem fotos ou vídeos!",
    "Add photos to this place" : "Adicionar fotos a este espaço",
    "Cover photo for place {placeName}" : "Foto da capa do espaço {placeName}",
    "There is no place yet!" : "Ainda não há espaço!",
    "Cover photo for shared album {albumName}" : "Foto da capa do álbum compartilhado {albumName}",
    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
    "No tags yet" : "Ainda não há etiquetas",
    "Photos with tags will show up here" : "Fotos com etiquetas serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas as etiquetas",
    "One of the source folders does not exist" : "Uma das pastas de origem não existe",
    "Add to album" : "Adicionar a álbum",
    "Delete selection" : "Excluir seleção",
    "No photos or videos in here" : "Não há fotos ou vídeos aqui",
    "Unassigned faces" : "Rostos não atribuídos",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Failed to fetch collection." : "Falha ao obter a coleção.",
    "Failed to fetch collections list." : "Falha ao obter a lista de coleções.",
    "Failed to fetch faces list." : "Falha ao obter a lista de rostos.",
    "Error fetching files" : "Erro ao buscar arquivos",
    "All your media" : "Todas as suas mídias",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbuns Compartilhados",
    "Shared album {title}" : "Álbum compartilhado {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos com etiqueta",
    "Tagged photo {title}" : "Foto com etiqueta {title}",
    "{title}'s face" : "Rosto de {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalhes",
    "Failed to rename {oldName} to {faceName}" : "Falha ao renomear {oldName} para {faceName}",
    "Failed to delete {faceName}" : "Falha ao excluir {faceName}",
    "Failed to delete {fileId}" : "Falha ao excluir {fileId}",
    "Failed to delete {fileName}" : "Falha ao excluir {fileName}",
    "Failed to set favorite state for {fileId}" : "Falha ao definir o estado de favorito para {fileId}",
    "Failed to set favorite state for {fileName}" : "Falha ao definir o estado de favorito para {fileName}",
    "Could not load photos folder" : "Não foi possível carregar a pasta de fotos",
    "One of the source folders does not exists" : "Uma das pastas de origem não existe",
    "Add" : "Adicionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/pt_BR.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Link público",
    "Photos" : "Fotos",
    "On This Day" : "Neste Dia",
    "Your memories under your control" : "Suas memórias sob seu controle",
    "All media" : "Todas as mídias",
    "Videos" : "Vídeos",
    "Albums" : "Álbuns",
    "Collaborative albums" : "Álbuns colaborativos",
    "People" : "Pessoas",
    "Folders" : "Pastas",
    "Favorites" : "Favoritos",
    "On this day" : "Neste dia",
    "Shared with you" : "Compartilhado com você",
    "Tags" : "Etiquetas",
    "Places" : "Lugares",
    "Map" : "Mapa",
    "Photos settings" : "Configurações de fotos",
    "Mark selection as favorite" : "Marcar seleção como favorito",
    "Add selection to favorites" : "Adicionar seleção aos favoritos",
    "Remove selection from favorites" : "Remover seleção dos favoritos",
    "This name is already in use." : "Este nome já está em uso.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" não é permitido dentro de um nome de arquivo.",
    "Invalid filename." : "Nome de arquivo inválido.",
    "Name of the album" : "Nome do álbum",
    "Location of the album" : "Localização do álbum",
    "Back" : "Voltar",
    "Add collaborators" : "Adicionar colaboradores",
    "Save" : "Salvar",
    "Create album" : "Criar álbum",
    "Add to Album" : "Adicionar ao Álbum",
    "Add selection to album {albumName}" : "Adicionar seleção ao álbum {albumName}",
    "Shared by" : "Compartilhado por",
    "Create a new album." : "Criar um novo álbum.",
    "Create new album" : "Criar novo álbum",
    "New album" : "Novo álbum",
    "_%n item_::_%n photos and videos_" : ["%n item","%n fotos e vídeos","%n fotos e vídeos"],
    "Failed to fetch collaborators list." : "Falha ao obter a lista de colaboradores.",
    "Failed to update album." : "Falha ao atualizar álbum.",
    "Add people or groups who can edit your album" : "Adicione pessoas ou grupos que podem editar seu álbum",
    "Search people or groups" : "Pesquisar pessoas ou grupos",
    "No recommendations. Start typing." : "Sem recomendações. Comece a digitar.",
    "Copy the public link" : "Copiar link público",
    "Public link copied!" : "Link público copiado!",
    "Copy public link" : "Copiar link público",
    "Delete the public link" : "Excluir link público",
    "Create public link share" : "Criar compartilhamento de link público",
    "Share via public link" : "Compartilhar via link público",
    "This collection does not exist" : "Esta coleção não existe",
    "An error occurred" : "Ocorreu um erro",
    "No picture for this day" : "Nenhuma foto para este dia",
    "Picture taken on this day will show up here." : "Uma foto tirada neste dia aparecerá aqui.",
    "More photos from this day" : "Mais fotos deste dia",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto não atribuída","%n fotos não atribuídas","%n fotos não atribuídas"],
    "Favorite" : "Favorito",
    "Favorite image, open the full size \"{name}\" image" : "Imagem favorita, abrir a imagem \"{name}\" em tamanho real",
    "Open the full size \"{name}\" image" : "Abrir a imagem \"{name}\" no tamanho real",
    "Select image {imageName}" : "Selecionar imagem {imageName}",
    "Open the \"{name}\" folder" : "Abrir pasta \"{name}\"",
    "Go back" : "Voltar",
    "Select a custom date range" : "Selecione um intervalo de datas personalizado",
    "Select a date range" : "Selecione um intervalo de datas",
    "Date range" : "Intervalo de datas",
    "Select filters" : "Selecione filtros",
    "Dates" : "Datas",
    "Jump to specific date in list" : "Ir para uma data específica na lista",
    "Jump to {date}" : "Ir para {date}",
    "Add to {destination}" : "Adicionar a {destination}",
    "The destination folder is owned by {owner}" : "A pasta de destino pertence a {owner}",
    "There are no photos or videos yet!" : "Ainda não há fotos ou vídeos!",
    "_{years} year ago_::_{years} years ago_" : ["há {years} ano","há {years} anos","há {years} anos"],
    "Squared photos view" : "Visualização de fotos quadradas",
    "Delete source directory" : "Excluir diretório de origem",
    "Pick folder" : "Selecionar pasta",
    "Select a source folder for your media" : "Selecione uma pasta de origem para sua mídia",
    "Media folders" : "Pastas de mídia",
    "Choose the folders from where photos and videos are shown." : "Escolha as pastas de onde as fotos e os vídeos são exibidos.",
    "All folders" : "Todas as pastas",
    "Add a Photos source for the timelines" : "Adicione uma fonte de Fotos para as linhas do tempo",
    "Add folder" : "Adicionar pasta",
    "Home" : "Início",
    "Select the default upload location for your media" : "Selecione o local de upload padrão para sua mídia",
    "Upload folder" : "Pasta para uploads",
    "General" : "Geral",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos","%n fotos"],
    "Unselect all" : "Desmarcar todos",
    "Add photos to this album" : "Adicionar fotos a este álbum",
    "Manage collaborators for this album" : "Gerenciar colaboradores para este álbum",
    "Open actions menu" : "Abrir menu de ações",
    "Edit album details" : "Modificar detalhes do álbum",
    "Download all files in album" : "Baixar todos os arquivos do álbum",
    "Delete album" : "Excluir álbum",
    "Download selected files" : "Baixar arquivos selecionados",
    "Remove selection from album" : "Remover seleção do álbum",
    "This album does not have any photos or videos yet!" : "Este álbum ainda não tem fotos ou vídeos!",
    "Add photos to {albumName}" : "Adicionar fotos a {albumName}",
    "Manage collaborators" : "Gerenciar colaboradores",
    "Save collaborators for this album." : "Salvar colaboradores deste álbum.",
    "Cover photo for album {albumName}" : "Foto da capa do álbum {albumName}",
    "There is no album yet!" : "Ainda não existe um álbum!",
    "This person could not be found" : "Não foi possível encontrar essa pessoa",
    "Rename person" : "Renomear pessoa",
    "Merge with different person" : "Unir com outra pessoa",
    "Download selected photos" : "Baixar fotos selecionadas",
    "Remove from favorites" : "Remover dos favoritos",
    "Remove person" : "Remover pessoa",
    "Name of this person" : "Nome desta pessoa",
    "Save." : "Salvar.",
    "Merge person" : "Unir pessoa",
    "Move to different person" : "Mover para uma pessoa diferente",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mover foto para uma pessoa diferente","Mover fotos para uma pessoa diferente","Mover fotos para uma pessoa diferente"],
    "_Remove photo from person_::_Remove photos from person_" : ["Remover foto desta pessoa","Remover fotos desta pessoa","Remover fotos desta pessoa"],
    "This might take some time depending on the size of your photo library." : "Isso pode levar algum tempo, dependendo do tamanho de sua biblioteca de fotos.",
    "Recognized people will show up here" : "Pessoas reconhecidas aparecerão aqui",
    "This folder does not exist" : "Esta pasta não existe",
    "Loading folders…" : "Carregando pastas…",
    "No photos in here" : "Não há fotos aqui",
    "Taken on {date} at {time}" : "Tirada em {data} às {time}",
    "This place does not have any photos or videos yet!" : "Este espaço ainda não tem fotos ou vídeos!",
    "Add photos to this place" : "Adicionar fotos a este espaço",
    "Cover photo for place {placeName}" : "Foto da capa do espaço {placeName}",
    "There is no place yet!" : "Ainda não há espaço!",
    "Cover photo for shared album {albumName}" : "Foto da capa do álbum compartilhado {albumName}",
    "Back to tags overview" : "Voltar para a visão geral das etiquetas",
    "No photos with this tag yet" : "Ainda não há fotos com esta etiqueta",
    "No tags yet" : "Ainda não há etiquetas",
    "Photos with tags will show up here" : "Fotos com etiquetas serão mostradas aqui",
    "Popular tags" : "Etiquetas populares",
    "All tags" : "Todas as etiquetas",
    "Create new album from filters" : "Criar novo álbum a partir de filtros",
    "One of the source folders does not exist" : "Uma das pastas de origem não existe",
    "Add to album" : "Adicionar a álbum",
    "Delete selection" : "Excluir seleção",
    "No photos or videos in here" : "Não há fotos ou vídeos aqui",
    "Unassigned faces" : "Rostos não atribuídos",
    "Failed to fetch collection." : "Falha ao obter a coleção.",
    "Failed to fetch collections list." : "Falha ao obter a lista de coleções.",
    "Failed to fetch faces list." : "Falha ao obter a lista de rostos.",
    "Error fetching files" : "Erro ao buscar arquivos",
    "All your media" : "Todas as suas mídias",
    "Album {title}" : "Álbum {title}",
    "Shared Albums" : "Álbuns Compartilhados",
    "Shared album {title}" : "Álbum compartilhado {title}",
    "Public album {title}" : "Álbum público {title}",
    "Tagged photos" : "Fotos com etiqueta",
    "Tagged photo {title}" : "Foto com etiqueta {title}",
    "{title}'s face" : "Rosto de {title}",
    "Last week" : "Última semana",
    "Last Month" : "Último Mês",
    "Custom…" : "Personalizado…",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalhes",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Falha ao adicionar {fileBaseName} à coleção {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Falha ao excluir {fileBaseName}",
    "Failed to create {collectionFileName}" : "Falha ao criar {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Falha ao renomear {currentCollectionFileName} para {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Falha ao atualizar as propriedades de {collectionFileName} com {properties}",
    "Delete collection" : "Excluir coleção",
    "Leave shared album" : "Deixar o álbum compartilhado",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Tem certeza de que deseja excluir {collectionName}? Esta ação não pode ser desfeita.",
    "Failed to delete {collectionFileName}" : "Falha ao excluir {collectionFileName}",
    "Cancel" : "Cancelar",
    "Confirm" : "Confirmar",
    "Failed to move {fileBaseName} to person {faceName}" : "Falha ao mover {fileBaseName} à pessoa {faceName}",
    "Failed to remove {fileBaseName}" : "Falha ao remover {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Falha ao renomear {oldName} para {faceName}",
    "Failed to delete {faceName}" : "Falha ao excluir {faceName}",
    "Failed to delete {fileId}" : "Falha ao excluir {fileId}",
    "Failed to delete {fileName}" : "Falha ao excluir {fileName}",
    "Failed to set favorite state for {fileId}" : "Falha ao definir o estado de favorito para {fileId}",
    "Failed to set favorite state for {fileName}" : "Falha ao definir o estado de favorito para {fileName}",
    "Could not load photos folder" : "Não foi possível carregar a pasta de fotos",
    "Group" : "Grupo",
    "Remove {collaboratorLabel} from the collaborators list" : "Remover {collaboratorLabel} da lista de colaboradores",
    "Back to {folder}" : "Voltar para {folder}",
    "Share this folder" : "Compartilhar esta pasta",
    "Enable squared photos view" : "Ativar exibição de fotos quadradas",
    "Choose default Photos upload and Albums location" : "Escolha o local padrão para upload de Fotos e Álbuns",
    "Choose a different folder" : "Escolha uma pasta diferente",
    "View" : "Exibição",
    "Choose the folder where photos and albums are uploaded to." : "Escolha a pasta na qual as fotos e os álbuns serão carregados.",
    "Loading folders …" : "Carregando pastas …",
    "Add" : "Adicionar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
